Js

Struct Js 

pub struct Js { /* private fields */ }
JavaScript source and captured values for a runtime expression.

Captured Rust values are serialized into the source. Embedding it in a view escapes it for the surrounding HTML context.

Implementations

Source

impl Js

pub fn source(js: impl Into<Cow<'static, str>>) -> Self

Source without captured values.

pub fn builder() -> JsBuilder

Starts source that interleaves captured values.

pub fn to_source(&self) -> String

Returns executable JavaScript, including serialized captured values.

The source expects the runtime context to be available as cx. It is not escaped for embedding in HTML.