ProcedureSurrogate

Struct ProcedureSurrogate 

pub struct ProcedureSurrogate<P> { /* private fields */ }
Available on crate feature router only.
A procedure captured by a runtime expression.

Serializes the endpoint URL for the browser and checks the argument and return types of call.

Implementations

Source

impl<P: TypedProcedure> ProcedureSurrogate<P>

pub const fn new(procedure: P, url: &'static str) -> Self

Pairs a procedure with the URL that serves its calls.

pub async fn call( &self, _args: <P::Args as Surrogated>::Surrogate, ) -> <P::Output as Surrogated>::Surrogate

Invokes the procedure from the client side.

Panics

Always panics; procedures can only be invoked from the client runtime.