pub struct Js { /* private fields */ }Expand description
JavaScript source and captured values for a runtime expression.
Captured Rust values are serialized into the source. Embedding it in a view escapes it for the surrounding HTML context.
Implementations