pub struct LinkPropsBuilder<'__a, H, __href = href>where
H: AttributeValueViewParts + Send,{ /* private fields */ }Expand description
Typestate builder for LinkProps, created by LinkProps::builder(). build() becomes available once every required property has been set.
Implementations
Sourceimpl<'__a, H, __href> LinkPropsBuilder<'__a, H, __href>where
H: AttributeValueViewParts + Send,
impl<'__a, H, __href> LinkPropsBuilder<'__a, H, __href>where
H: AttributeValueViewParts + Send,
Sourcepub fn href(self, href: H) -> LinkPropsBuilder<'__a, H, Set>
pub fn href(self, href: H) -> LinkPropsBuilder<'__a, H, Set>
The URL to open. Use href! for pages in your app.
Sourcepub fn prefetch(self, prefetch: impl Into<Option<PrefetchMode>>) -> Self
pub fn prefetch(self, prefetch: impl Into<Option<PrefetchMode>>) -> Self
When to load the page before the user follows the link. Uses
prefetch_mode if omitted.
Sourcepub fn attrs(self, attrs: Attributes) -> Self
pub fn attrs(self, attrs: Attributes) -> Self
Additional HTML attributes to put on the link.