pub struct ProcedureSurrogate<P> { /* private fields */ }Available on crate feature
router only.Expand description
A procedure captured by a runtime expression.
Serializes the endpoint URL for the browser and checks the argument and
return types of call.
Implementations
Sourceimpl<P: TypedProcedure> ProcedureSurrogate<P>
impl<P: TypedProcedure> ProcedureSurrogate<P>
Sourcepub const fn new(procedure: P, url: &'static str) -> Self
pub const fn new(procedure: P, url: &'static str) -> Self
Pairs a procedure with the URL that serves its calls.
Sourcepub async fn call(
&self,
_args: <P::Args as Surrogated>::Surrogate,
) -> <P::Output as Surrogated>::Surrogate
pub async fn call( &self, _args: <P::Args as Surrogated>::Surrogate, ) -> <P::Output as Surrogated>::Surrogate
Invokes the procedure from the client side.
Panics
Always panics; procedures can only be invoked from the client runtime.